---
title: Tutorial overview
---

1. [Setting up `derivepassphrase vault` for three accounts, with a master passphrase][BASIC_SETUP_PASSPHRASE]
2. [Using a master SSH key with `derivepassphrase vault` on existing accounts][BASIC_SETUP_SSH_KEY]

[BASIC_SETUP_PASSPHRASE]: basic-setup-passphrase.md
[BASIC_SETUP_SSH_KEY]: basic-setup-ssh-key.md
